# This program will take the Unigene unique seq file as the input and parse out the Accession
# SID, and CID for each cluster and put it in a database.
#
# The Unigene unique seq file is Xx.seq.uniq from ftp://ftp.ncbi.nih.gov/repository/UniGene/,
# where Xx is the species abbreviation (Xl for Xenopus laevis, Hs for Homo sapiens).

#!/usr/bin/perl


use strict;
use warnings;

use DBI;			# This module is required to work with databases.
use DBD::ODBC;		# This module is the driver required for MS Access.


my $DatabaseName = "XenopusBuild48Orientation";
# Holds the name of the Database or its alias.
# Make sure the Database is registered.


my $file;			# Holds the name of the Unigene unique file.
my $line;			# Used read from the Unigene unique file line by line.
my $dbh;			# DB handler.
my $DBQuery;		# Holds DB queries.


print "Please enter the name (including the PATH) of the Unigene Unique file:";
$file = <STDIN>;
chomp( $file );
$file =~ s/^\s+// if ( $file ); # get rid of leading spaces.
$file =~ s/\s+$// if ( $file ); # get rid of trailing spaces.


open( FILE, "<$file" ) or die( "Couldn't open $file $! \n" );
# FILE is the filehandle for the Unigene unique file.


# Connect to the database.
$dbh = DBI->connect( "DBI:ODBC:$DatabaseName", "", "", { RaiseError => 1 } );
# Empty strings are username and password, none set on this machine.


# Start reading from the Unigene unique file.
$line = <FILE>;
chomp( $line );


while ( $line )
{
	my $Accession;	# Holds the Accession of the Unigene cluster representative sequence.
	my $SID;		# Holds the Unigene sequence identifier of the $Accession.
	my $CID;		# Holds the Unigene Cluster ID.
	my @array;		# Holds result of split function.

	if ( $line =~ m/^>/)
	{
		$line =~ m/\/gb=.*\/gi=/;
		# Will match the GenBank Accession Number. The form of the Unigene Description line
		# is: "AGENCOURT_11343981 NICHD_XGC_Tad2 Xenopus laevis cDNA clone IMAGE:6881639 5', 
		# mRNA sequence /clone=IMAGE:6881639 /clone_end=5' /gb=CB208784 /gi=29148784 /ug=Xl.24713
		# /len=926"
		$Accession = $&;
		# $& stores the string that was matched.
		$Accession =~ s/\/gb=//; # getting rid of the /gb= 
		$Accession =~ s/ \/gi=//; # getting rid of the /gi=
		
		
		@array = split( / /, $line );
		$array[0] =~ m/UG\|.*/;
		# Will match the Unigene Sequence ID.
		$SID = $&;
		# $& stores the string that was matched.
		$SID =~ s/UG\|//; # getting rid of the UG|.
				
		
		$line =~ m/\/ug=.*\/len=/;
		# Will match the Unigene Cluster ID.
		$CID = $&;
		# $& stores the string that was matched.
		$CID =~ s/\/ug=//; # getting rid of the /ug= 
		$CID =~ s/ \/len=//; # getting rid of the /len=


		$DBQuery = "INSERT INTO AccToSID ( Accession, SID, CID )
							VALUES ( '$Accession', '$SID', '$CID' );";
				
		$dbh->do( $DBQuery );
		
	}

	# Get next line from the Unigene unique file.
	$line = <FILE>;
	chomp( $line ) if ( $line );

}

close( FILE );




